==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_StoryArchive.pm <==
package WebGUI::i18n::Dutch::Asset_StoryArchive;
use utf8;
our $I18N = {
  'add a story' => {
    'lastUpdated' => '1246977093',
    'message' => 'Voeg een verhaal toe'
  },
  'addStoryUrl' => {
    'lastUpdated' => '1248971508',
    'message' => 'De URL waar de gebruiker een verhaal kan toevoegen.'
  },
  'approval workflow' => {
    'lastUpdated' => '1248971570',
    'message' => 'Goedkeurings workflow voor verhalen'
  },
  'approval workflow help' => {
    'lastUpdated' => '1248971609',
    'message' => 'Kies een workflow die uitgevoerd moet worden als een verhaal ingestuurd wordt.'
  },
  'approvalWorkflowId' => {
    'lastUpdated' => '1248971644',
    'message' => 'De GUID van de workflow die uitgevoerd wordt als een verhaal ingestuurd wordt.'
  },
  'archive after' => {
    'lastUpdated' => '1248971661',
    'message' => 'Archiveer verhalen na'
  },
  'archive after help' => {
    'lastUpdated' => '1248971708',
    'message' => 'Na deze tijd worden verhalen gearchiveerd en worden niet meer in lijsten getoond. Stel in op 0 voor het uitschakelen van archiveren.'
  },
  'archiveAfter' => {
    'lastUpdated' => '1248971741',
    'message' => 'De hoeveelheid tijd in seconden. Na deze tijd worden verhalen gearchiveerd.'
  },
  'asset title' => {
    'lastUpdated' => '1246977113',
    'message' => 'De titel van dit asset'
  },
  'asset url' => {
    'lastUpdated' => '1250839914',
    'message' => 'De url van dit asset.'
  },
  'assetName' => {
    'lastUpdated' => '1248971958',
    'message' => 'Verhalenarchief'
  },
  'asset_loop' => {
    'lastUpdated' => '1248971989',
    'message' => 'Een functie die de eerste 50 assets die overeenkomen met het trefwoord ophaalt.'
  },
  'atomUrl' => {
    'lastUpdated' => '1249028206',
    'message' => 'De URL van de Atom feed van dit Verhalenarchief.'
  },
  'canPostStories' => {
    'lastUpdated' => '1249028227',
    'message' => 'Een functie die waar is als de gebruiker verhalen kan insturen.'
  },
  'creationDate' => {
    'lastUpdated' => '1249028268',
    'message' => 'De epoch tijd waarop dit verhaal is gemaakt of ingestuurd naar het verhalenarchief.'
  },
  'date_loop' => {
    'lastUpdated' => '1249028354',
    'message' => 'Een functie die verhalen per dag ophaalt, met subfuncties voor elke dag. Er wordt een bepaald aantal per pagina weergegeven via paginatie.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1248182556',
    'message' => 'Een ikoon om dit verhaal te verwijderen. Als de gebruiker het verhaal niet mag verwijderen, of als hun gebruikersinterfaceniveau te laag is zal deze variabele geen inhoud hebben.'
  },
  'edit story template' => {
    'lastUpdated' => '1248968627',
    'message' => 'Bewerk verhaal sjabloon'
  },
  'edit story template help' => {
    'lastUpdated' => '1249028390',
    'message' => 'Het sjabloon waarmee Verhalen worden toegevoegd en bewerkt.'
  },
  'editIcon' => {
    'lastUpdated' => '1248182737',
    'message' => 'Een ikoon om dit verhaal te bewerken. Als de gebruiker het verhaal niet mag bewerken, of als hun
gebruikersinterfaceniveau te laag is zal deze variabele geen inhoud
hebben.'
  },
  'editStoryTemplateId' => {
    'lastUpdated' => '1249028418',
    'message' => 'DE GUID van het sjabloon waarmee verhalen toegevoegd en bewerkt worden.'
  },
  'epochDate' => {
    'lastUpdated' => '1249028461',
    'message' => 'De epoch tijd die overeenkomt met het begin van de dag waarop een verhaal aan het archief is toegevoegd.'
  },
  'group to post' => {
    'lastUpdated' => '1248968615',
    'message' => 'Groep voor plaatsen'
  },
  'group to post help' => {
    'lastUpdated' => '1249028479',
    'message' => 'De groep die verhalen aan dit verhalenarchief kan toevoegen.'
  },
  'groupToPost' => {
    'lastUpdated' => '1248968889',
    'message' => 'De GUID van de groep die verhalen aan dit archief kan toevoegen.'
  },
  'keyword' => {
    'lastUpdated' => '1247043426',
    'message' => 'Het trefwoord voor deze lijst met assets'
  },
  'keyword list template' => {
    'lastUpdated' => '1249028539',
    'message' => 'Verhalenarchief, trewoordenlijst sjabloon'
  },
  'keyword list template help' => {
    'lastUpdated' => '1249028598',
    'message' => 'Het sjabloon dat gebruikt wordt voor het tonen van een lijst met assets die overeenkomen met een trefwoord tijdens het exporteren van het verhalenarchief.'
  },
  'keywordCloud' => {
    'lastUpdated' => '1249029154',
    'message' => 'De verzameling links voor de trefwoorden voor verhalen in het verhalenarchief.'
  },
  'keywordListTemplateId' => {
    'lastUpdated' => '1249029203',
    'message' => 'Het GUID van ht sjabloon dat de lijst met assets maakt die overeenkomen met een trefwoord tijdens het exporteren van het Verhalenarchief.'
  },
  'photo width' => {
    'lastUpdated' => '1248968603',
    'message' => 'Breedte foto'
  },
  'photo width help' => {
    'lastUpdated' => '1248968739',
    'message' => 'Foto\'s die door de YUI Carousel getoond worden hebben dezelfde grootte nodig om goed te functioneren. Deze breedte wordt voor alle foto\'s gebruikt. Stel in op 0 om deze functie uit te zetten.'
  },
  'photoWidth' => {
    'lastUpdated' => '1248968667',
    'message' => 'De breedte die toegekent wordt aan alle foto\'s van verhalen in dit archief.'
  },
  'rich editor' => {
    'lastUpdated' => '1249029242',
    'message' => 'Rich editor'
  },
  'rich editor help' => {
    'lastUpdated' => '1249029280',
    'message' => 'De tekstverwerker die laat zien hoe een verhaal eruit gaat zien tijdens het bewerken.'
  },
  'richEditorId' => {
    'lastUpdated' => '1249029325',
    'message' => 'Het GUID van de rich editor de gebruikt wordt voor het bewerken van de inhoud van een verhaal.'
  },
  'rssUrl' => {
    'lastUpdated' => '1248968867',
    'message' => 'De URL van de RSS van dit verhaal archief.'
  },
  'searchButton' => {
    'lastUpdated' => '1248969218',
    'message' => 'Een knop met geinternationaliseerd label voor het insturen van het zoekformulier. Dez variabele is leeg als het verhalen archief ge&euml;xporeerd wordt als HTML.'
  },
  'searchFooter' => {
    'lastUpdated' => '1249029417',
    'message' => 'HTML code waarmee het zoekformulier be&euml;indigd wordt. Deze variabele is leeg als het verhalenarchief als HTML wordt geexporteerd.'
  },
  'searchForm' => {
    'lastUpdated' => '1249030229',
    'message' => 'Het tekstveld waar gebruikers trefwoorden kunnen invoeren om op te zoeken. Deze variabele is leeg als het Verhalenarchief als HTML ge&euml;xporteerd wordt.'
  },
  'searchHeader' => {
    'lastUpdated' => '1249030222',
    'message' => 'HTML code waar het formulier mee geopend wordt. Deze variabele is leeg als het Verhalenarchief als HTML ge&euml;xporteerd wordt.'
  },
  'stories per page' => {
    'lastUpdated' => '1249030238',
    'message' => 'Verhalen per pagina'
  },
  'stories per page help' => {
    'lastUpdated' => '1249030295',
    'message' => 'Het aantal verhalen dat per pagina getoond wordt. Als het asset ge&euml;xporteerd wordt zal de gegenereerde pagina standard 10 pagina\'s met verhalen bevatten.'
  },
  'story template' => {
    'lastUpdated' => '1249030303',
    'message' => 'Verhaal sjabloon'
  },
  'story template help' => {
    'lastUpdated' => '1249030329',
    'message' => 'Het sjabloon waarmee verhalen getoond worden vanuit dit verhalenarchief.'
  },
  'storyTemplateId' => {
    'lastUpdated' => '1249030353',
    'message' => 'Het GUID van het sjabbloon waarmee verhalen assets getoond worden.'
  },
  'story_loop' => {
    'lastUpdated' => '1248968831',
    'message' => 'Een functie die alle verhalen ophaalt die ingevoerd zijn op de dag van deze epoch datum.'
  },
  'storyarchive asset template variables title' => {
    'lastUpdated' => '1248968824',
    'message' => 'Verhaal archief asset sjabloon variabelen'
  },
  'template' => {
    'lastUpdated' => '1248972014',
    'message' => 'Verhalenarchief sjabloon'
  },
  'template help' => {
    'lastUpdated' => '1249030375',
    'message' => 'Het sjabloon waarmee het verhalenarchief getoond wordt.'
  },
  'templateId' => {
    'lastUpdated' => '1248972139',
    'message' => 'De GUID van het sjabloon die gebruikt wordt voor het tonen van het verhalenarchief.'
  },
  'title' => {
    'lastUpdated' => '1247043480',
    'message' => 'De titel van een verhaal'
  },
  'url' => {
    'lastUpdated' => '1247043494',
    'message' => 'De URL om een verhaal te bekijken'
  },
  'view template' => {
    'lastUpdated' => '1248972106',
    'message' => 'Sjabloon Verhalenarchief'
  }
}
;

1;

==> webgui_7.9.30.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_StoryArchive.pm <==
package WebGUI::i18n::Dutch::Asset_StoryArchive;
use utf8;
our $I18N = {
  'add a story' => {
    'lastUpdated' => '1246977093',
    'message' => 'Voeg een verhaal toe'
  },
  'addStoryUrl' => {
    'lastUpdated' => '1248971508',
    'message' => 'De URL waar de gebruiker een verhaal kan toevoegen.'
  },
  'alphabetically' => {
    'lastUpdated' => '1280491603',
    'message' => 'Alfabetisch'
  },
  'approval workflow' => {
    'lastUpdated' => '1248971570',
    'message' => 'Goedkeurings workflow voor verhalen'
  },
  'approval workflow help' => {
    'lastUpdated' => '1248971609',
    'message' => 'Kies een workflow die uitgevoerd moet worden als een verhaal ingestuurd wordt.'
  },
  'approvalWorkflowId' => {
    'lastUpdated' => '1248971644',
    'message' => 'De GUID van de workflow die uitgevoerd wordt als een verhaal ingestuurd wordt.'
  },
  'archive after' => {
    'lastUpdated' => '1248971661',
    'message' => 'Archiveer verhalen na'
  },
  'archive after help' => {
    'lastUpdated' => '1248971708',
    'message' => 'Na deze tijd worden verhalen gearchiveerd en worden niet meer in lijsten getoond. Stel in op 0 voor het uitschakelen van archiveren.'
  },
  'archiveAfter' => {
    'lastUpdated' => '1248971741',
    'message' => 'De hoeveelheid tijd in seconden. Na deze tijd worden verhalen gearchiveerd.'
  },
  'asset title' => {
    'lastUpdated' => '1246977113',
    'message' => 'De titel van dit asset'
  },
  'asset url' => {
    'lastUpdated' => '1250839914',
    'message' => 'De url van dit asset.'
  },
  'assetName' => {
    'lastUpdated' => '1248971958',
    'message' => 'Verhalenarchief'
  },
  'asset_loop' => {
    'lastUpdated' => '1248971989',
    'message' => 'Een functie die de eerste 50 assets die overeenkomen met het trefwoord ophaalt.'
  },
  'atomUrl' => {
    'lastUpdated' => '1249028206',
    'message' => 'De URL van de Atom feed van dit Verhalenarchief.'
  },
  'canPostStories' => {
    'lastUpdated' => '1249028227',
    'message' => 'Een functie die waar is als de gebruiker verhalen kan insturen.'
  },
  'chronologically' => {
    'lastUpdated' => '1280491612',
    'message' => 'Chronologisch'
  },
  'creationDate' => {
    'lastUpdated' => '1249028268',
    'message' => 'De epoch tijd waarop dit verhaal is gemaakt of ingestuurd naar het verhalenarchief.'
  },
  'date_loop' => {
    'lastUpdated' => '1249028354',
    'message' => 'Een functie die verhalen per dag ophaalt, met subfuncties voor elke dag. Er wordt een bepaald aantal per pagina weergegeven via paginatie.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1248182556',
    'message' => 'Een ikoon om dit verhaal te verwijderen. Als de gebruiker het verhaal niet mag verwijderen, of als hun gebruikersinterfaceniveau te laag is zal deze variabele geen inhoud hebben.'
  },
  'edit story template' => {
    'lastUpdated' => '1248968627',
    'message' => 'Bewerk verhaal sjabloon'
  },
  'edit story template help' => {
    'lastUpdated' => '1249028390',
    'message' => 'Het sjabloon waarmee Verhalen worden toegevoegd en bewerkt.'
  },
  'editIcon' => {
    'lastUpdated' => '1248182737',
    'message' => 'Een ikoon om dit verhaal te bewerken. Als de gebruiker het verhaal niet mag bewerken, of als hun
gebruikersinterfaceniveau te laag is zal deze variabele geen inhoud
hebben.'
  },
  'editStoryTemplateId' => {
    'lastUpdated' => '1249028418',
    'message' => 'DE GUID van het sjabloon waarmee verhalen toegevoegd en bewerkt worden.'
  },
  'epochDate' => {
    'lastUpdated' => '1249028461',
    'message' => 'De epoch tijd die overeenkomt met het begin van de dag waarop een verhaal aan het archief is toegevoegd.'
  },
  'group to post' => {
    'lastUpdated' => '1248968615',
    'message' => 'Groep voor plaatsen'
  },
  'group to post help' => {
    'lastUpdated' => '1249028479',
    'message' => 'De groep die verhalen aan dit verhalenarchief kan toevoegen.'
  },
  'groupToPost' => {
    'lastUpdated' => '1248968889',
    'message' => 'De GUID van de groep die verhalen aan dit archief kan toevoegen.'
  },
  'keyword' => {
    'lastUpdated' => '1247043426',
    'message' => 'Het trefwoord voor deze lijst met assets'
  },
  'keyword list template' => {
    'lastUpdated' => '1249028539',
    'message' => 'Verhalenarchief, trewoordenlijst sjabloon'
  },
  'keyword list template help' => {
    'lastUpdated' => '1249028598',
    'message' => 'Het sjabloon dat gebruikt wordt voor het tonen van een lijst met assets die overeenkomen met een trefwoord tijdens het exporteren van het verhalenarchief.'
  },
  'keywordCloud' => {
    'lastUpdated' => '1249029154',
    'message' => 'De verzameling links voor de trefwoorden voor verhalen in het verhalenarchief.'
  },
  'keywordListTemplateId' => {
    'lastUpdated' => '1249029203',
    'message' => 'Het GUID van ht sjabloon dat de lijst met assets maakt die overeenkomen met een trefwoord tijdens het exporteren van het Verhalenarchief.'
  },
  'photo width' => {
    'lastUpdated' => '1248968603',
    'message' => 'Breedte foto'
  },
  'photo width help' => {
    'lastUpdated' => '1248968739',
    'message' => 'Foto\'s die door de YUI Carousel getoond worden hebben dezelfde grootte nodig om goed te functioneren. Deze breedte wordt voor alle foto\'s gebruikt. Stel in op 0 om deze functie uit te zetten.'
  },
  'photoWidth' => {
    'lastUpdated' => '1248968667',
    'message' => 'De breedte die toegekent wordt aan alle foto\'s van verhalen in dit archief.'
  },
  'rich editor' => {
    'lastUpdated' => '1249029242',
    'message' => 'Rich editor'
  },
  'rich editor help' => {
    'lastUpdated' => '1249029280',
    'message' => 'De tekstverwerker die laat zien hoe een verhaal eruit gaat zien tijdens het bewerken.'
  },
  'richEditorId' => {
    'lastUpdated' => '1249029325',
    'message' => 'Het GUID van de rich editor de gebruikt wordt voor het bewerken van de inhoud van een verhaal.'
  },
  'rssUrl' => {
    'lastUpdated' => '1248968867',
    'message' => 'De URL van de RSS van dit verhaal archief.'
  },
  'searchButton' => {
    'lastUpdated' => '1248969218',
    'message' => 'Een knop met geinternationaliseerd label voor het insturen van het zoekformulier. Dez variabele is leeg als het verhalen archief ge&euml;xporeerd wordt als HTML.'
  },
  'searchFooter' => {
    'lastUpdated' => '1249029417',
    'message' => 'HTML code waarmee het zoekformulier be&euml;indigd wordt. Deze variabele is leeg als het verhalenarchief als HTML wordt geexporteerd.'
  },
  'searchForm' => {
    'lastUpdated' => '1249030229',
    'message' => 'Het tekstveld waar gebruikers trefwoorden kunnen invoeren om op te zoeken. Deze variabele is leeg als het Verhalenarchief als HTML ge&euml;xporteerd wordt.'
  },
  'searchHeader' => {
    'lastUpdated' => '1249030222',
    'message' => 'HTML code waar het formulier mee geopend wordt. Deze variabele is leeg als het Verhalenarchief als HTML ge&euml;xporteerd wordt.'
  },
  'sortAlphabeticallyChronologically' => {
    'lastUpdated' => '1280491629',
    'message' => 'Sorteervolgorde'
  },
  'sortAlphabeticallyChronologically description' => {
    'lastUpdated' => '1280491739',
    'message' => 'Toon berichten in alfabetische of chronologische volgorde.'
  },
  'stories per page' => {
    'lastUpdated' => '1249030238',
    'message' => 'Verhalen per pagina'
  },
  'stories per page help' => {
    'lastUpdated' => '1249030295',
    'message' => 'Het aantal verhalen dat per pagina getoond wordt. Als het asset ge&euml;xporteerd wordt zal de gegenereerde pagina standard 10 pagina\'s met verhalen bevatten.'
  },
  'story template' => {
    'lastUpdated' => '1249030303',
    'message' => 'Verhaal sjabloon'
  },
  'story template help' => {
    'lastUpdated' => '1249030329',
    'message' => 'Het sjabloon waarmee verhalen getoond worden vanuit dit verhalenarchief.'
  },
  'storyTemplateId' => {
    'lastUpdated' => '1249030353',
    'message' => 'Het GUID van het sjabbloon waarmee verhalen assets getoond worden.'
  },
  'story_loop' => {
    'lastUpdated' => '1248968831',
    'message' => 'Een functie die alle verhalen ophaalt die ingevoerd zijn op de dag van deze epoch datum.'
  },
  'storyarchive asset template variables title' => {
    'lastUpdated' => '1248968824',
    'message' => 'Verhaal archief asset sjabloon variabelen'
  },
  'template' => {
    'lastUpdated' => '1248972014',
    'message' => 'Verhalenarchief sjabloon'
  },
  'template help' => {
    'lastUpdated' => '1249030375',
    'message' => 'Het sjabloon waarmee het verhalenarchief getoond wordt.'
  },
  'templateId' => {
    'lastUpdated' => '1248972139',
    'message' => 'De GUID van het sjabloon die gebruikt wordt voor het tonen van het verhalenarchief.'
  },
  'title' => {
    'lastUpdated' => '1247043480',
    'message' => 'De titel van een verhaal'
  },
  'url' => {
    'lastUpdated' => '1247043494',
    'message' => 'De URL om een verhaal te bekijken'
  },
  'view template' => {
    'lastUpdated' => '1248972106',
    'message' => 'Sjabloon Verhalenarchief'
  }
}
;

1;
